==> kubernetes-model-apiextensions-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/ExternalDocumentationBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ExternalDocumentationBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent;
    Boolean validationEnabled;

    public ExternalDocumentationBuilder() {
        this(true);
    }

    public ExternalDocumentationBuilder(Boolean validationEnabled) {
        this(new ExternalDocumentation(), validationEnabled);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent) {
        this(fluent, true);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ExternalDocumentation(), validationEnabled);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
        this(fluent, instance, true);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withDescription(instance.getDescription()); 
        fluent.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
        this(instance,true);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withDescription(instance.getDescription()); 
        this.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation build() {
        ExternalDocumentation buildable = new ExternalDocumentation(fluent.getDescription(),fluent.getUrl());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ExternalDocumentationBuilder that = (ExternalDocumentationBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.4.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/ExternalDocumentationBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ExternalDocumentationBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public ExternalDocumentationBuilder() {
        this(true);
    }

    public ExternalDocumentationBuilder(java.lang.Boolean validationEnabled) {
        this(new ExternalDocumentation(), validationEnabled);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent) {
        this(fluent, true);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new ExternalDocumentation(), validationEnabled);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
        this(fluent, instance, true);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentationFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withDescription(instance.getDescription()); 
        fluent.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance) {
        this(instance,true);
    }

    public ExternalDocumentationBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withDescription(instance.getDescription()); 
        this.withUrl(instance.getUrl()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.ExternalDocumentation build() {
        ExternalDocumentation buildable = new ExternalDocumentation(fluent.getDescription(),fluent.getUrl());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ExternalDocumentationBuilder that = (ExternalDocumentationBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
